@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -26,13 +26,11 @@ class MailImporter::FilterEvolution_v3Private
 {
 public:
     FilterEvolution_v3Private()
-        : mImportDirDone(-1)
-        , mTotalDir(-1)
     {
     }
 
-    int mImportDirDone;
-    int mTotalDir;
+    int mImportDirDone = -1;
+    int mTotalDir = -1;
 };
 /** Default constructor. */
 FilterEvolution_v3::FilterEvolution_v3()
@@ -52,6 +50,15 @@ FilterEvolution_v3::~FilterEvolution_v3()
     delete d;
 }
 
+QString FilterEvolution_v3::isMailerFound()
+{
+    QDir directory(FilterEvolution_v3::defaultSettingsPath());
+    if (directory.exists()) {
+        return i18nc("name of evolution application", "Evolution (v3)");
+    }
+    return {};
+}
+
 QString FilterEvolution_v3::defaultSettingsPath()
 {
     return QDir::homePath() + QLatin1String("/.local/share/evolution/mail/local/");
